@@ -182,10 +182,13 @@ class QCticAPI:
         """
 
         params = GetJobsQuerySchema().dump(kwargs)
+        status = params.pop("status", [])
+        url = url_concat(self._build_url("/jobs"), params)
 
-        req = self._request(
-            url=url_concat(self._build_url("/jobs"), params),
-            method="GET")
+        for item in status:
+            url = url_concat(url, {"status": item})
+
+        req = self._request(url=url, method="GET")
 
         _logger.debug(_format_req(req))
         res = await self.client.fetch(req)
