@@ -44,6 +44,13 @@ class GetJobsQuerySchema(Schema):
         if start and end and end <= start:
             raise ValidationError("end_dtime must be greater than start_dtime")
 
+    @pre_dump
+    def str_status_to_list(self, data, **kwargs):
+        if isinstance(data.get("status", None), str):
+            data["status"] = [data["status"]]
+
+        return data
+
 
 class JobSchema(Schema):
     job_id = fields.Str(required=True)
