@@ -3,7 +3,7 @@ import uuid
 import pytest
 
 from qctic.api import QCticAPI
-from qctic.backend import CticErwinQasmSimulator
+from qctic.backend import QCticQasmSimulator
 from qctic.job import QCticJob
 from qctic.provider import QCticProvider
 from tests.utils import fake_qobj
@@ -19,7 +19,7 @@ def provider(httpserver):
 
 @pytest.fixture(scope="function")
 def job(provider):
-    backend = provider.get_backend(CticErwinQasmSimulator.NAME)
+    backend = provider.get_backend(QCticQasmSimulator.NAME)
     job_id = str(uuid.uuid4())
     qobj = fake_qobj()
     return QCticJob(backend, job_id, qobj)
